@@ -8,7 +8,8 @@ import {
     TupleOfflineStorageNameService,
     TupleStorageFactoryService,
     TupleStorageFactoryServiceWeb,
-    SqlFactoryService,
+    WebSqlBrowserFactoryService,
+    WebSqlFactoryService,
 } from "@synerty/vortexjs";
 import { staticRoutes } from "./app.routes";
 import { peekRootServices } from "./app.services";
@@ -29,7 +30,6 @@ import { FormsModule } from "@angular/forms";
 import { NzIconModule } from "ng-zorro-antd/icon";
 import { ComponentsModule } from "./core/components";
 import { PagesModule } from "./pages/pages.module";
-import { AngularSvgIconModule } from "angular-svg-icon";
 
 registerLocaleData(en);
 
@@ -52,13 +52,15 @@ export function tupleOfflineStorageNameServiceFactory() {
         HttpClientModule,
         ComponentsModule,
         PagesModule,
-        AngularSvgIconModule.forRoot(),
     ],
     providers: [
         { provide: NZ_I18N, useValue: en_US },
         { provide: LOCAL_PROVIDER_TOKEN, useValue: mobile_en_US },
         ...peekRootServices,
-        SqlFactoryService,
+        {
+            provide: WebSqlFactoryService,
+            useClass: WebSqlBrowserFactoryService,
+        },
         {
             provide: TupleStorageFactoryService,
             useClass: TupleStorageFactoryServiceWeb,
