@@ -3,20 +3,13 @@ import { BrowserModule } from "@angular/platform-browser";
 import { RouterModule } from "@angular/router";
 import { FormsModule } from "@angular/forms";
 import { NzIconModule } from "ng-zorro-antd/icon";
-import { HomePage, ConfigPage, UnknownRoutePage } from "./";
-import { NzAlertModule } from "ng-zorro-antd/alert";
+import { ConfigPage, HomePage, UnknownRoutePage } from "./";
 
 const PAGES = [HomePage, ConfigPage, UnknownRoutePage];
 
 @NgModule({
     declarations: PAGES,
-    imports: [
-        RouterModule,
-        FormsModule,
-        BrowserModule,
-        NzIconModule,
-        NzAlertModule,
-    ],
+    imports: [RouterModule, FormsModule, BrowserModule, NzIconModule],
     exports: PAGES,
 })
 export class PagesModule {}
